#!/bin/sh
#
# (C) Daniel Sundberg 2000
# This is free software and you may do whatever 
# you want to with this according to the GPL.
#
# This program requires smbclient, fixsmbcop, cut & sh.
# Lists the share on a computer.
# Args:
# $1 : Computer
#
if [ -z "$1" ]; then
    echo "Usage: list_shares [COMPUTER]"
else 
    smbclient -L $1 -N | awk '{print $1}' | fixsmbcop Sharename --------- _NEWLINE
fi
